def ttl_cache(maxsize=128, ttl=600, timer=time.monotonic, typed=False):
	"""
	Decorator to wrap a function with a memoizing callable that saves
	up to `maxsize` results based on a Least Recently Used (LRU)
	algorithm with a per-item time-to-live (TTL) value.
	"""
	cache = {}

	t = lambda *a, **k: timer()

	if maxsize < 1:
		raise RuntimeError("Maxsize must be greater than zero.")

	def wrapper(*args, **kw):
		key = hash(*args) + hash(t(*args, **kw))
		if typed and not kw.get("_ttl"):
			raise TypeError("_ttl is required.")
		if typed:
			# If not provided, the wrapped function must have type annotations.
			if not kw.get("_cache_key"