from typing import List, Tuple


def find_closest_elements(numbers: List[float]) -> Tuple[float, float]:
    """ From a supplied list of numbers (of length at least two) select and return two that are the closest to each
    other and return them in order (smaller number, larger number).
    >>> find_closest_elements([1.0, 2.0, 3.0, 4.0, 5.0, 2.2])
    (2.0, 2.2)
    >>> find_closest_elements([1.0, 2.0, 3.0, 4.0, 5.0, 2.0])
    (2.0, 2.0)
    """
    if len(numbers) < 2:
        raise ValueError("Input must be of length at least 2")
    differences = [abs(number - numbers[n - 1]) for n in range(len(numbers) - 1)]
    minimum = min(differences)
    differences_sorted = sorted(differences)
    return elements_with_minimum_distance_to_each_other(differences_sorted, minimum)

